@@ -592,13 +592,16 @@ def engine_status(
     engines = response.json().get("engines", [])
     engine = resolve_engine(name_or_id, engines)
 
-    # Get attached studios info
-    response = make_api_request(
-        "GET", f"/engines/{engine['instance_id']}/attached-studios"
-    )
-    attached_studios = []
-    if response.status_code == 200:
-        attached_studios = response.json().get("studios", [])
+    # Get detailed engine status including idle detector info
+    response = make_api_request("GET", f"/engines/{engine['instance_id']}")
+    if response.status_code != 200:
+        console.print("[red]❌ Failed to fetch engine details[/red]")
+        raise typer.Exit(1)
+    
+    engine_details = response.json()
+    engine = engine_details.get("engine", engine)  # Use detailed info if available
+    idle_detector = engine_details.get("idle_detector", {})
+    attached_studios = engine_details.get("attached_studios", [])
 
     # Calculate costs
     launch_time = parse_launch_time(engine["launch_time"])
@@ -642,6 +645,37 @@ def engine_status(
                 status_lines.append(f"  • Idle Detector: {health.get('idle_detector_timer', 'unknown')}")
         except Exception:
             pass
+    
+    # Idle detector status (from new API endpoint)
+    if idle_detector.get("available"):
+        status_lines.append("")
+        status_lines.append("[bold]Idle Detector:[/bold]")
+        
+        # Overall status
+        if idle_detector["status"] == "active":
+            status_lines.append("  [green]✓ Engine ACTIVE[/green]")
+        else:
+            idle_seconds = idle_detector.get("idle_seconds", 0)
+            idle_threshold = idle_detector.get("idle_threshold", 1800)
+            idle_minutes = idle_seconds // 60
+            threshold_minutes = idle_threshold // 60
+            status_lines.append(f"  [yellow]⏱ Engine IDLE ({idle_minutes}/{threshold_minutes} minutes)[/yellow]")
+        
+        # Coffee lock
+        if idle_detector.get("coffee_lock"):
+            status_lines.append(f"  • [cyan]☕ Caffeinated for another {idle_detector['coffee_lock']}[/cyan]")
+        
+        # SSH sessions
+        ssh_sessions = idle_detector.get("ssh_sessions", [])
+        if ssh_sessions:
+            status_lines.append(f"  • [blue]SSH Sessions ({len(ssh_sessions)}):[/blue]")
+            for session in ssh_sessions:
+                status_lines.append(f"    - {session['tty']} (pid {session['pid']}, idle {session['idle_time']}) from {session['from_ip']}")
+        
+        # IDE connections
+        ide_conn = idle_detector.get("ide_connections")
+        if ide_conn:
+            status_lines.append(f"  • [magenta]🖥  IDE connected ({ide_conn['connection_count']} connections)[/magenta]")
 
     if attached_studios:
         status_lines.append("")
@@ -978,7 +1012,7 @@ def coffee(
     else:
         console.print(f"Pouring coffee for [cyan]{engine['name']}[/cyan] for {duration}…")
 
-    # Use SSM to run the engine keep-alive command
+    # Use SSM to run the engine coffee command
     ssm = boto3.client("ssm", region_name="us-east-1")
     try:
         response = ssm.send_command(
@@ -986,7 +1020,7 @@ def coffee(
             DocumentName="AWS-RunShellScript",
             Parameters={
                 "commands": [
-                    ("engine-coffee --cancel" if cancel else f"engine-coffee {seconds_total}")
+                    ("/usr/local/bin/engine-coffee --cancel" if cancel else f"/usr/local/bin/engine-coffee {seconds_total}")
                 ],
                 "executionTimeout": ["60"],
             },
